
# GOUDA

[![Anaconda-Server Badge](https://anaconda.org/smullan/gouda/badges/version.svg)](https://anaconda.org/smullan/gouda)
[![pypi](https://img.shields.io/pypi/v/gouda)](https://pypi.org/project/GOUDA/)

Good Old Utilities for Data Analysis!

## Description

These are a bunch of data/image/filepath/etc utilities that I've made to help with my research projects. Feel free to use them as you would like, and I'd appreciate it if you make a pull request for any fixes/optimizations you may find.

## Installation

gouda can be installed using [pip](https://pypi.org/project/pip/)

    pip install gouda

Alternatively, you can install gouda with [conda](https://docs.conda.io/projects/conda/en/latest/) or [mamba](https://github.com/mamba-org/mamba)

    conda install gouda -c smullan
